@@ -1,17 +1,23 @@
 """
     Url router for the dashboard common
 """
-from django.contrib.auth.decorators import login_required
-from django.urls import re_path
-from django.urls import reverse_lazy
-from django.conf.urls import include
 
-from core_dashboard_common_app.views.common import (
-    ajax,
-    views as dashboard_common_app_common_views,
-)
+from django.conf.urls import include
+from django.contrib import admin
+from django.urls import re_path
+
+from core_dashboard_common_app.views.common import ajax
+from core_file_preview_app.views.user.ajax import get_blob_preview
+from core_main_app.admin import core_admin_site
 
 urlpatterns = [
+    re_path(r"^admin/", admin.site.urls),
+    re_path(r"^core-admin/", core_admin_site.urls),
+    re_path(r"^", include("core_main_app.urls")),
+    re_path(r"^", include("core_curate_app.urls")),
+    re_path(
+        r"^edit-record", ajax.edit_record, name="core_dashboard_edit_record"
+    ),
     re_path(
         r"^delete-document",
         ajax.delete_document,
@@ -23,15 +29,8 @@ urlpatterns = [
         name="core_dashboard_change_owner_document",
     ),
     re_path(
-        r"^edit-record", ajax.edit_record, name="core_dashboard_edit_record"
+        r"^get_blob_preview",
+        get_blob_preview,
+        name="core_file_preview_app_get_blob_preview",
     ),
-    re_path(
-        r"^forms$",
-        login_required(
-            dashboard_common_app_common_views.DashboardForms.as_view(),
-            login_url=reverse_lazy("core_main_app_login"),
-        ),
-        name="core_dashboard_common_forms",
-    ),
-    re_path(r"^tz_detect/", include("tz_detect.urls")),
 ]
